@@ -53,8 +53,8 @@
 #'
 #' # Conduct two subgroup analyses
 #' #
-#' mu1 <- update(m1, byvar = age, bylab = "Age group")
-#' mu2 <- update(m1, byvar = region, bylab = "Region")
+#' mu1 <- update(m1, subgroup = age, subgroup.name = "Age group")
+#' mu2 <- update(m1, subgroup = region, subgroup.name = "Region")
 #'
 #' # Combine subgroup meta-analyses and show forest plot with subgroup
 #' # results
@@ -132,26 +132,23 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   }
   ##  
   for (i in n.i) {
-    if (!inherits(args[[i]], "meta"))
-      stop("All elements of argument '...' must be of ",
-           "class 'meta'.",
-           call. = FALSE)
-    ##
     if (inherits(args[[i]], "metabind"))
       stop("Elements of argument '...' may not be of ",
            "class 'metabind'.",
            call. = FALSE)
+    ##
+    if (!inherits(args[[i]], "meta"))
+      stop("All elements of argument '...' must be of class 'meta'.",
+           call. = FALSE)
+    else
+      args[[i]] <- updateversion(args[[i]])
   }
   
   
   is.subgroup <- rep(FALSE, n.meta)
   ##
   for (i in n.i) {
-    if (!inherits(args[[i]], "meta"))
-      stop("All elements of argument '...' must be of class 'meta'.",
-           call. = FALSE)
-    ##
-    if (!is.null(args[[i]]$byvar))
+    if (!is.null(args[[i]]$subgroup))
       is.subgroup[i] <- TRUE
   }
   
@@ -168,7 +165,7 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
     name <- rep("", n.meta)
     ##
     for (i in n.i)
-      name[i] <- replaceNULL(args[[i]]$bylab)
+      name[i] <- replaceNULL(args[[i]]$subgroup.name)
     ##
     if (all(is.na(name)))
       name <- paste0("meta", n.i)
@@ -207,11 +204,11 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
     ##
     meth.i <- data.frame(sm = m.i$sm,
                          method = m.i$method,
-                         level = m.i$level.comb,
-                         level.comb = m.i$level.comb,
+                         level = m.i$level.ma,
+                         level.ma = m.i$level.ma,
                          level.predict = m.i$level.predict,
-                         comb.fixed = m.i$comb.fixed,
-                         comb.random = m.i$comb.random,
+                         fixed = m.i$fixed,
+                         random = m.i$random,
                          hakn = m.i$hakn,
                          method.tau = m.i$method.tau,
                          tau.preset = replaceNULL(m.i$tau.preset),
@@ -229,8 +226,8 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
                          label.left = m.i$label.left,
                          label.right = m.i$label.right,
                          ##
-                         print.byvar = FALSE,
-                         byseparator = "",
+                         print.subgroup.name = FALSE,
+                         sep.subgroup = "",
                          warn = replaceNULL(m.i$warn, FALSE),
                          ##
                          backtransf = m.i$backtransf,
@@ -249,12 +246,12 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   ## Unify some settings
   ##
   if (missing(pooled)) {
-    if (all(meth$comb.fixed) & all(!meth$comb.random))
+    if (all(meth$fixed) & all(!meth$random))
       pooled <- "fixed"
-    else if (all(!meth$comb.fixed) & all(meth$comb.random))
+    else if (all(!meth$fixed) & all(meth$random))
       pooled <- "random"
     else {
-      if (any(meth$comb.fixed)) {
+      if (any(meth$fixed)) {
         warning3 <-
           paste("Note, results from random effects model extracted.",
                 "Use argument pooled = \"fixed\" for results of",
@@ -266,12 +263,12 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   }
   ##
   if (pooled == "fixed") {
-    meth$comb.fixed <- TRUE
-    meth$comb.random <- FALSE
+    meth$fixed <- TRUE
+    meth$random <- FALSE
   }
   else {
-    meth$comb.fixed <- FALSE
-    meth$comb.random <- TRUE
+    meth$fixed <- FALSE
+    meth$random <- TRUE
   }
   
   
@@ -378,6 +375,9 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
                            n.c = replaceNULL(m.i$n.c.w),
                            df.hakn = replaceNULL(m.i$df.hakn.w),
                            ##
+                           n.harmonic.mean = m.i$n.harmonic.mean.w,
+                           t.harmonic.mean = m.i$t.harmonic.mean.w,
+                           ##
                            k = m.i$k.w,
                            k.all = m.i$k.all.w,
                            Q = m.i$Q.w,
@@ -416,6 +416,11 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
                            n.c = sum(replaceNULL(m.i$n.c)),
                            df.hakn = replaceNULL(m.i$df.hakn),
                            ##
+                           n.harmonic.mean =
+                             1 / mean(1 / replaceNULL(m.i$n)),
+                           t.harmonic.mean =
+                             1 / mean(1 / replaceNULL(m.i$time)),
+                           ##
                            k = m.i$k,
                            k.all = length(m.i$TE),
                            Q = m.i$Q,
@@ -463,6 +468,11 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
                             pval.random = m.i$pval.random,
                             df.hakn = replaceNULL(m.i$df.hakn),
                             ##
+                            n.harmonic.mean.ma =
+                              1 / mean(1 / replaceNULL(m.i$n)),
+                            t.harmonic.mean.ma =
+                              1 / mean(1 / replaceNULL(m.i$time)),
+                            ##
                             seTE.predict = m.i$seTE.predict,
                             lower.predict = m.i$lower.predict,
                             upper.predict = m.i$upper.predict,
@@ -664,7 +674,7 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
       }
     }
     ##
-    study.i$byvar <- name[i]
+    study.i$subgroup <- name[i]
     ##
     if (i == 1)
       study <- study.i
@@ -673,9 +683,9 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   }
   
   
-  if (length(unique(study$byvar)) == 1) {
+  if (length(unique(study$subgroup)) == 1) {
     res <- c(as.list(study), as.list(meth[1, ]), as.list(overall))
-    res$byvar <- NULL
+    res$subgroup <- NULL
   }
   else
     res <- c(as.list(study), as.list(meth[1, ]),
@@ -683,6 +693,8 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   ##
   ##
   res$data <- data
+  res$n.harmonic.mean <- data$n.harmonic.mean
+  res$t.harmonic.mean <- data$t.harmonic.mean
   ##
   res$call <- match.call()
   res$version <- packageDescription("meta")$Version
@@ -737,6 +749,9 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   res$lower.I2 <- makeunique(res$lower.I2)
   res$upper.I2 <- makeunique(res$upper.I2)
   ##
+  res$n.harmonic.mean.ma <- makeunique(res$n.harmonic.mean.ma)
+  res$t.harmonic.mean.ma <- makeunique(res$t.harmonic.mean.ma)
+  ##
   res$Rb <- makeunique(res$Rb)
   res$lower.Rb <- makeunique(res$lower.Rb)
   res$upper.Rb <- makeunique(res$upper.Rb)
@@ -763,9 +778,9 @@ metabind <- function(..., name, pooled, backtransf, outclab) {
   res$is.subgroup <- is.subgroup
 
 
-  if (!is.null(res$byvar)) {
-    res$bylab <- "meta-analysis"
-    res$bylevs <- unique(res$byvar)
+  if (!is.null(res$subgroup)) {
+    res$subgroup.name <- "meta-analysis"
+    res$bylevs <- unique(res$subgroup)
     res$w.fixed <- rep(0, length(res$w.fixed))
     res$w.fixed.w <- rep(0, length(res$w.fixed.w))
     res$w.random <- rep(0, length(res$w.random))
