@@ -41,11 +41,11 @@
 #'   \code{"CM.EL"}, see Details.
 #' @param level The level used to calculate confidence intervals for
 #'   individual studies.
-#' @param level.comb The level used to calculate confidence intervals
-#'   for pooled estimates.
-#' @param comb.fixed A logical indicating whether a fixed effect
-#'   meta-analysis should be conducted.
-#' @param comb.random A logical indicating whether a random effects
+#' @param level.ma The level used to calculate confidence intervals
+#'   for meta-analysis estimates.
+#' @param fixed A logical indicating whether a fixed effect / common
+#'   effect meta-analysis should be conducted.
+#' @param random A logical indicating whether a random effects
 #'   meta-analysis should be conducted.
 #' @param overall A logical indicating whether overall summaries
 #'   should be reported. This argument is useful in a meta-analysis
@@ -112,27 +112,32 @@
 #' @param label.c Label for control group.
 #' @param label.left Graph label on left side of forest plot.
 #' @param label.right Graph label on right side of forest plot.
-#' @param byvar An optional vector containing grouping information
-#'   (must be of same length as \code{event.e}).
-#' @param bylab A character string with a label for the grouping
-#'   variable.
-#' @param print.byvar A logical indicating whether the name of the
-#'   grouping variable should be printed in front of the group labels.
-#' @param byseparator A character string defining the separator
-#'   between label and levels of grouping variable.
+#' @param subgroup An optional vector to conduct a meta-analysis with
+#'   subgroups.
+#' @param subgroup.name A character string with a name for the
+#'   subgroup variable.
+#' @param print.subgroup.name A logical indicating whether the name of
+#'   the subgroup variable should be printed in front of the group
+#'   labels.
+#' @param sep.subgroup A character string defining the separator
+#'   between name of subgroup variable and subgroup label.
 #' @param test.subgroup A logical value indicating whether to print
 #'   results of test for subgroup differences.
+#' @param byvar Deprecated argument (replaced by 'subgroup').
 #' @param keepdata A logical indicating whether original data (set)
 #'   should be kept in meta object.
 #' @param warn A logical indicating whether warnings should be printed
 #'   (e.g., if \code{incr} is added to studies with zero cell
 #'   frequencies).
+#' @param warn.deprecated A logical indicating whether warnings should
+#'   be printed if deprecated arguments are used.
 #' @param control An optional list to control the iterative process to
 #'   estimate the between-study variance \eqn{\tau^2}. This argument
 #'   is passed on to \code{\link[metafor]{rma.uni}} or
 #'   \code{\link[metafor]{rma.glmm}}, respectively.
 #' @param \dots Additional arguments passed on to
 #'   \code{\link[metafor]{rma.glmm}} function.
+#' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @details
 #' Calculation of fixed and random effects estimates for meta-analyses
@@ -157,8 +162,8 @@
 #' \subsection{Meta-analysis method}{
 #' 
 #' By default, both fixed effect and random effects models are
-#' considered (see arguments \code{comb.fixed} and
-#' \code{comb.random}). If \code{method} is \code{"MH"} (default), the
+#' considered (see arguments \code{fixed} and
+#' \code{random}). If \code{method} is \code{"MH"} (default), the
 #' Mantel-Haenszel method is used to calculate the fixed effect
 #' estimate (Greenland & Robbins, 1985); if \code{method} is
 #' \code{"Inverse"}, inverse variance weighting is used for pooling;
@@ -303,7 +308,7 @@
 #' 
 #' A prediction interval for the proportion in a new study (Higgins et
 #' al., 2009) is calculated if arguments \code{prediction} and
-#' \code{comb.random} are \code{TRUE}. Note, the definition of
+#' \code{random} are \code{TRUE}. Note, the definition of
 #' prediction intervals varies in the literature. This function
 #' implements equation (12) of Higgins et al., (2009) which proposed a
 #' \emph{t} distribution with \emph{K-2} degrees of freedom where
@@ -312,7 +317,7 @@
 #'
 #' \subsection{Subgroup analysis}{
 #' 
-#' Argument \code{byvar} can be used to conduct subgroup analysis for
+#' Argument \code{subgroup} can be used to conduct subgroup analysis for
 #' a categorical covariate. The \code{\link{metareg}} function can be
 #' used instead for more than one categorical covariate or continuous
 #' covariates.
@@ -332,14 +337,14 @@
 #' 
 #' Internally, both fixed effect and random effects models are
 #' calculated regardless of values choosen for arguments
-#' \code{comb.fixed} and \code{comb.random}. Accordingly, the estimate
+#' \code{fixed} and \code{random}. Accordingly, the estimate
 #' for the random effects model can be extracted from component
 #' \code{TE.random} of an object of class \code{"meta"} even if
-#' argument \code{comb.random = FALSE}. However, all functions in R
+#' argument \code{random = FALSE}. However, all functions in R
 #' package \bold{meta} will adequately consider the values for
-#' \code{comb.fixed} and \code{comb.random}. E.g. function
+#' \code{fixed} and \code{random}. E.g. function
 #' \code{\link{print.meta}} will not print results for the random
-#' effects model if \code{comb.random = FALSE}.
+#' effects model if \code{random = FALSE}.
 #' }
 #' 
 #' @return
@@ -350,7 +355,7 @@
 #'   defined above.}
 #' \item{sm, method, incr, allincr, addincr, model.glmm, warn,}{As
 #'   defined above.}
-#' \item{level, level.comb, comb.fixed, comb.random,}{As defined
+#' \item{level, level.ma, fixed, random,}{As defined
 #'   above.}
 #' \item{overall, overall.hetstat,}{As defined above.}
 #' \item{hakn, adhoc.hakn, method.tau, method.tau.ci,}{As defined above.}
@@ -358,7 +363,7 @@
 #' \item{tau.common, title, complab, outclab,}{As defined above.}
 #' \item{label.e, label.c, label.left, label.right,}{As defined
 #'   above.}
-#' \item{byvar, bylab, print.byvar, byseparator}{As defined above.}
+#' \item{subgroup, subgroup.name, print.subgroup.name, sep.subgroup}{As defined above.}
 #' \item{TE, seTE}{Estimated treatment effect and standard error of
 #'   individual studies.}
 #' \item{lower, upper}{Lower and upper confidence interval limits for
@@ -416,85 +421,85 @@
 #'   Hartung-Knapp method (only if \code{hakn = TRUE}).}
 #' \item{k.MH}{Number of studies combined in meta-analysis using
 #'   Mantel-Haenszel method.}
-#' \item{bylevs}{Levels of grouping variable - if \code{byvar} is not
+#' \item{bylevs}{Levels of grouping variable - if \code{subgroup} is not
 #'   missing.}
 #' \item{TE.fixed.w, seTE.fixed.w}{Estimated treatment effect and
 #'   standard error in subgroups (fixed effect model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.fixed.w, upper.fixed.w}{Lower and upper confidence
 #'   interval limits in subgroups (fixed effect model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{statistic.fixed.w, pval.fixed.w}{z-value and p-value for test of
 #'   treatment effect in subgroups (fixed effect model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{TE.random.w, seTE.random.w}{Estimated treatment effect and
 #'   standard error in subgroups (random effects model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.random.w, upper.random.w}{Lower and upper confidence
 #'   interval limits in subgroups (random effects model) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{statistic.random.w, pval.random.w}{z-value or t-value and
 #'   corresponding p-value for test of treatment effect in subgroups
-#'   (random effects model) - if \code{byvar} is not missing.}
+#'   (random effects model) - if \code{subgroup} is not missing.}
 #' \item{w.fixed.w, w.random.w}{Weight of subgroups (in fixed and
-#'   random effects model) - if \code{byvar} is not missing.}
+#'   random effects model) - if \code{subgroup} is not missing.}
 #' \item{df.hakn.w}{Degrees of freedom for test of treatment effect
-#'   for Hartung-Knapp method in subgroups - if \code{byvar} is not
+#'   for Hartung-Knapp method in subgroups - if \code{subgroup} is not
 #'   missing and \code{hakn = TRUE}.}
 #' \item{event.e.w}{Number of events in experimental group in
-#'   subgroups - if \code{byvar} is not missing.}
+#'   subgroups - if \code{subgroup} is not missing.}
 #' \item{time.e.w}{Total person time in subgroups (experimental
-#'   group) - if \code{byvar} is not missing.}
+#'   group) - if \code{subgroup} is not missing.}
 #' \item{n.e.w}{Number of observations in experimental group in
-#'   subgroups - if \code{byvar} is not missing.}
+#'   subgroups - if \code{subgroup} is not missing.}
 #' \item{event.c.w}{Number of events in control group in subgroups -
-#'   if \code{byvar} is not missing.}
+#'   if \code{subgroup} is not missing.}
 #' \item{time.c.w}{Total person time in subgroups (control group) - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{n.c.w}{Number of observations in control group in subgroups -
-#'   if \code{byvar} is not missing.}
+#'   if \code{subgroup} is not missing.}
 #' \item{k.w}{Number of studies combined within subgroups - if
-#'   \code{byvar} is not missing.}
-#' \item{k.all.w}{Number of all studies in subgroups - if \code{byvar}
+#'   \code{subgroup} is not missing.}
+#' \item{k.all.w}{Number of all studies in subgroups - if \code{subgroup}
 #'   is not missing.}
 #' \item{Q.w.fixed}{Overall within subgroups heterogeneity statistic Q
-#'   (based on fixed effect model) - if \code{byvar} is not missing.}
+#'   (based on fixed effect model) - if \code{subgroup} is not missing.}
 #' \item{Q.w.random}{Overall within subgroups heterogeneity statistic
-#'   Q (based on random effects model) - if \code{byvar} is not
+#'   Q (based on random effects model) - if \code{subgroup} is not
 #'   missing (only calculated if argument \code{tau.common} is TRUE).}
 #' \item{df.Q.w}{Degrees of freedom for test of overall within
-#'   subgroups heterogeneity - if \code{byvar} is not missing.}
+#'   subgroups heterogeneity - if \code{subgroup} is not missing.}
 #' \item{pval.Q.w.fixed}{P-value of within subgroups heterogeneity
-#'   statistic Q (based on fixed effect model) - if \code{byvar} is
+#'   statistic Q (based on fixed effect model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{pval.Q.w.random}{P-value of within subgroups heterogeneity
-#'   statistic Q (based on random effects model) - if \code{byvar} is
+#'   statistic Q (based on random effects model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{Q.b.fixed}{Overall between subgroups heterogeneity statistic
-#'   Q (based on fixed effect model) - if \code{byvar} is not
+#'   Q (based on fixed effect model) - if \code{subgroup} is not
 #'   missing.}
 #' \item{Q.b.random}{Overall between subgroups heterogeneity statistic
-#'   Q (based on random effects model) - if \code{byvar} is not
+#'   Q (based on random effects model) - if \code{subgroup} is not
 #'   missing.}
 #' \item{df.Q.b}{Degrees of freedom for test of overall between
-#'   subgroups heterogeneity - if \code{byvar} is not missing.}
+#'   subgroups heterogeneity - if \code{subgroup} is not missing.}
 #' \item{pval.Q.b.fixed}{P-value of between subgroups heterogeneity
-#'   statistic Q (based on fixed effect model) - if \code{byvar} is
+#'   statistic Q (based on fixed effect model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{pval.Q.b.random}{P-value of between subgroups heterogeneity
-#'   statistic Q (based on random effects model) - if \code{byvar} is
+#'   statistic Q (based on random effects model) - if \code{subgroup} is
 #'   not missing.}
 #' \item{tau.w}{Square-root of between-study variance within subgroups
-#'   - if \code{byvar} is not missing.}
+#'   - if \code{subgroup} is not missing.}
 #' \item{H.w}{Heterogeneity statistic H within subgroups - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.H.w, upper.H.w}{Lower and upper confidence limit for
-#'   heterogeneity statistic H within subgroups - if \code{byvar} is
+#'   heterogeneity statistic H within subgroups - if \code{subgroup} is
 #'   not missing.}
 #' \item{I2.w}{Heterogeneity statistic I\eqn{^2} within subgroups - if
-#'   \code{byvar} is not missing.}
+#'   \code{subgroup} is not missing.}
 #' \item{lower.I2.w, upper.I2.w}{Lower and upper confidence limit for
-#'   heterogeneity statistic I\eqn{^2} within subgroups - if \code{byvar} is
+#'   heterogeneity statistic I\eqn{^2} within subgroups - if \code{subgroup} is
 #'   not missing.}
 #' \item{keepdata}{As defined above.}
 #' \item{data}{Original data (set) used in function call (if
@@ -639,11 +644,11 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                     addincr = gs("addincr"),
                     model.glmm = "UM.FS",
                     ##
-                    level = gs("level"), level.comb = gs("level.comb"),
-                    comb.fixed = gs("comb.fixed"),
-                    comb.random = gs("comb.random"),
-                    overall = comb.fixed | comb.random,
-                    overall.hetstat = comb.fixed | comb.random,
+                    level = gs("level"), level.ma = gs("level.ma"),
+                    fixed = gs("fixed"),
+                    random = gs("random") | !is.null(tau.preset),
+                    overall = fixed | random,
+                    overall.hetstat = fixed | random,
                     ##
                     hakn = gs("hakn"), adhoc.hakn = gs("adhoc.hakn"),
                     method.tau =
@@ -676,12 +681,14 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                     label.left = gs("label.left"),
                     label.right = gs("label.right"),
                     ##
-                    byvar, bylab, print.byvar = gs("print.byvar"),
-                    byseparator = gs("byseparator"),
+                    subgroup, subgroup.name = NULL,
+                    print.subgroup.name = gs("print.subgroup.name"),
+                    sep.subgroup = gs("sep.subgroup"),
                     test.subgroup = gs("test.subgroup"),
+                    byvar,
                     ##
                     keepdata = gs("keepdata"),
-                    warn = gs("warn"),
+                    warn = gs("warn"), warn.deprecated = gs("warn.deprecated"),
                     ##
                     control = NULL,
                     ...
@@ -697,11 +704,6 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   sm <- setchar(sm, .settings$sm4inc)
   ##
   chklevel(level)
-  chklevel(level.comb)
-  chklogical(comb.fixed)
-  chklogical(comb.random)
-  chklogical(overall)
-  chklogical(overall.hetstat)
   ##
   chklogical(hakn)
   missing.adhoc.hakn <- missing(adhoc.hakn)
@@ -769,6 +771,45 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
               call. = FALSE)
     adhoc.hakn <- ""
   }
+  ##
+  ## Check for deprecated arguments in '...'
+  ##
+  args  <- list(...)
+  chklogical(warn.deprecated)
+  ##
+  level.ma <- deprecated(level.ma, missing(level.ma), args, "level.comb",
+                         warn.deprecated)
+  chklevel(level.ma)
+  ##
+  fixed <- deprecated(fixed, missing(fixed), args, "comb.fixed",
+                      warn.deprecated)
+  chklogical(fixed)
+  ##
+  random <- deprecated(random, missing(random), args, "comb.random",
+                       warn.deprecated)
+  chklogical(random)
+  ##
+  missing.subgroup.name <- missing(subgroup.name)
+  subgroup.name <-
+    deprecated(subgroup.name, missing.subgroup.name, args, "bylab",
+               warn.deprecated)
+  ##
+  print.subgroup.name <-
+    deprecated(print.subgroup.name, missing(print.subgroup.name),
+               args, "print.byvar", warn.deprecated)
+  print.subgroup.name <- replaceNULL(print.subgroup.name, FALSE)
+  chklogical(print.subgroup.name)
+  ##
+  sep.subgroup <-
+    deprecated(sep.subgroup, missing(sep.subgroup), args, "byseparator",
+               warn.deprecated)
+  if (!is.null(sep.subgroup))
+    chkchar(sep.subgroup, length = 1)
+  ##
+  ## Some more checks
+  ##
+  chklogical(overall)
+  chklogical(overall.hetstat)
   
   
   ##
@@ -818,15 +859,22 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                  data, enclos = sys.frame(sys.parent()))
   chknumeric(incr, min = 0)
   ##
-  ## Catch 'studlab', 'byvar', 'subset', and 'exclude' from data:
+  ## Catch 'studlab', 'subgroup', 'subset', and 'exclude' from data:
   ##
   studlab <- eval(mf[[match("studlab", names(mf))]],
                   data, enclos = sys.frame(sys.parent()))
   studlab <- setstudlab(studlab, k.All)
   ##
+  missing.subgroup <- missing(subgroup)
+  subgroup <- eval(mf[[match("subgroup", names(mf))]],
+                   data, enclos = sys.frame(sys.parent()))
+  missing.byvar <- missing(byvar)
   byvar <- eval(mf[[match("byvar", names(mf))]],
                 data, enclos = sys.frame(sys.parent()))
-  by <- !is.null(byvar)
+  ##
+  subgroup <- deprecated2(subgroup, missing.subgroup, byvar, missing.byvar,
+                          warn.deprecated)
+  by <- !is.null(subgroup)
   ##
   subset <- eval(mf[[match("subset", names(mf))]],
                  data, enclos = sys.frame(sys.parent()))
@@ -851,7 +899,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     chklength(incr, k.All, fun)
   ##
   if (by) {
-    chklength(byvar, k.All, fun)
+    chklength(subgroup, k.All, fun)
     chklogical(test.subgroup)
   }
   ##
@@ -877,7 +925,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   }
   if (!by & tau.common) {
     warning("Value for argument 'tau.common' set to FALSE as ",
-            "argument 'byvar' is missing.")
+            "argument 'subgroup' is missing.")
     tau.common <- FALSE
   }
   if (by & !tau.common & !is.null(tau.preset)) {
@@ -930,7 +978,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     data$.incr <- incr
     ##
     if (by)
-      data$.byvar <- byvar
+      data$.subgroup <- subgroup
     ##
     if (!missing.subset) {
       if (length(subset) == dim(data)[1])
@@ -969,7 +1017,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
       incr <- incr[subset]
     ##
     if (by)
-      byvar <- byvar[subset]
+      subgroup <- subgroup[subset]
     ##
     if (!null.n.e)
       n.e <- n.e[subset]
@@ -987,8 +1035,8 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## No meta-analysis for a single study
   ##
   if (k.all == 1) {
-    comb.fixed  <- FALSE
-    comb.random <- FALSE
+    fixed  <- FALSE
+    random <- FALSE
     prediction  <- FALSE
     overall <- FALSE
     overall.hetstat <- FALSE
@@ -1009,10 +1057,18 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   time.c  <- int2num(time.c)
   ##
   if (by) {
-    chkmiss(byvar)
-    byvar.name <- byvarname(mf[[match("byvar", names(mf))]])
-    bylab <- if (!missing(bylab) && !is.null(bylab)) bylab else byvar.name
+    chkmiss(subgroup)
+    ##
+    if (missing.subgroup.name & is.null(subgroup.name)) {
+      if (!missing.subgroup)
+        subgroup.name <- byvarname(mf[[match("subgroup", names(mf))]])
+      else if (!missing.byvar)
+        subgroup.name <- byvarname(mf[[match("byvar", names(mf))]])
+    }
   }
+  ##
+  if (!is.null(subgroup.name))
+    chkchar(subgroup.name, length = 1)
   
   
   ##
@@ -1136,7 +1192,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
       glmm.fixed <- rma.glmm(x1i = event.e[!exclude], t1i = time.e[!exclude],
                              x2i = event.c[!exclude], t2i = time.c[!exclude],
                              method = "FE", test = ifelse(hakn, "t", "z"),
-                             level = 100 * level.comb,
+                             level = 100 * level.ma,
                              measure = "IRR", model = model.glmm,
                              control = control,
                              ...)
@@ -1156,9 +1212,9 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                ##
                sm = sm,
                level = level,
-               level.comb = level.comb,
-               comb.fixed = comb.fixed,
-               comb.random = comb.random,
+               level.ma = level.ma,
+               fixed = fixed,
+               random = random,
                overall = overall,
                overall.hetstat = overall.hetstat,
                ##
@@ -1192,7 +1248,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     ## Estimate common tau-squared across subgroups
     hcc <- hetcalc(TE, seTE, method.tau, "",
                    if (method == "Inverse") TE.tau else TE.fixed,
-                   level.comb, byvar, control)
+                   level.ma, subgroup, control)
   }
   
   
@@ -1232,7 +1288,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ##
   if (method %in% c("MH", "Cochran", "GLMM")) {
     ##
-    ci.f <- ci(TE.fixed, seTE.fixed, level = level.comb)
+    ci.f <- ci(TE.fixed, seTE.fixed, level = level.ma)
     ##
     res$TE.fixed <- TE.fixed
     res$seTE.fixed <- seTE.fixed
@@ -1251,7 +1307,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                               x2i = event.c[!exclude], t2i = time.c[!exclude],
                               method = method.tau,
                               test = ifelse(hakn, "t", "z"),
-                              level = 100 * level.comb,
+                              level = 100 * level.ma,
                               measure = "IRR", model = model.glmm,
                               control = control,
                               ...)
@@ -1266,7 +1322,7 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     TE.random   <- as.numeric(glmm.random$b)
     seTE.random <- as.numeric(glmm.random$se)
     ##
-    ci.r <- ci(TE.random, seTE.random, level = level.comb,
+    ci.r <- ci(TE.random, seTE.random, level = level.ma,
                df = if (hakn) k - 1)
     ##
     res$w.random <- rep(NA, length(event.e))
@@ -1323,12 +1379,12 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     res$sign.lower.tau <- ""
     res$sign.upper.tau <- ""
     ##
-    H <- calcH(res$Q, res$df.Q, level.comb)
+    H <- calcH(res$Q, res$df.Q, level.ma)
     res$H <- H$TE
     res$lower.H <- H$lower
     res$upper.H <- H$upper
     ##
-    I2 <- isquared(res$Q, res$df.Q, level.comb)
+    I2 <- isquared(res$Q, res$df.Q, level.ma)
     res$I2 <- I2$TE
     res$lower.I2 <- I2$lower
     res$upper.I2 <- I2$upper
@@ -1342,9 +1398,9 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
     res$version.metafor <- packageDescription("metafor")$Version
     ##
     if (by) {
-      n.by <- length(unique(byvar[!exclude]))
+      n.by <- length(unique(subgroup[!exclude]))
       if (n.by > 1)
-        byvar.glmm <- factor(byvar[!exclude], bylevs(byvar[!exclude]))
+        subgroup.glmm <- factor(subgroup[!exclude], bylevs(subgroup[!exclude]))
       ##
       glmm.random.by <-
         try(suppressWarnings(rma.glmm(x1i = event.e[!exclude],
@@ -1352,10 +1408,11 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                                       x2i = event.c[!exclude],
                                       t2i = time.c[!exclude],
                                       mods =
-                                        if (n.by > 1) ~ byvar.glmm else NULL,
+                                        if (n.by > 1)
+                                          ~ subgroup.glmm else NULL,
                                       method = method.tau,
                               test = ifelse(hakn, "t", "z"),
-                              level = 100 * level.comb,
+                              level = 100 * level.ma,
                               measure = "IRR", model = model.glmm,
                               control = control,
                               ...)),
@@ -1371,10 +1428,11 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
                                       x2i = event.c[!exclude],
                                       t2i = time.c[!exclude],
                                       mods =
-                                        if (n.by > 1) ~ byvar.glmm else NULL,
+                                        if (n.by > 1)
+                                          ~ subgroup.glmm else NULL,
                                       method = "FE",
                                       test = ifelse(hakn, "t", "z"),
-                                      level = 100 * level.comb,
+                                      level = 100 * level.ma,
                                       measure = "IRR", model = model.glmm,
                                       control = control,
                                       ...))
@@ -1385,8 +1443,8 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
       Q.r <- glmm.random.by$QE.Wld
       df.Q.r <- glmm.random.by$k - glmm.random.by$p
       ##
-      H.r  <- calcH(Q.r, df.Q.r, level.comb)
-      I2.r <- isquared(Q.r, df.Q.r, level.comb)
+      H.r  <- calcH(Q.r, df.Q.r, level.ma)
+      I2.r <- isquared(Q.r, df.Q.r, level.ma)
       ##
       hcc <- list(tau2.resid = glmm.random.by$tau2,
                   lower.tau2.resid = NA,
@@ -1424,10 +1482,10 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
   ## Add results from subgroup analysis
   ##
   if (by) {
-    res$byvar <- byvar
-    res$bylab <- bylab
-    res$print.byvar <- print.byvar
-    res$byseparator <- byseparator
+    res$subgroup <- subgroup
+    res$subgroup.name <- subgroup.name
+    res$print.subgroup.name <- print.subgroup.name
+    res$sep.subgroup <- sep.subgroup
     res$test.subgroup <- test.subgroup
     res$tau.common <- tau.common
     ##
@@ -1437,8 +1495,9 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
       res <- c(res, subgroup(res, tau.preset))
     else {
       if (is.glmm)
-        res <- c(res, subgroup(res, NULL,
-                               factor(res$byvar, bylevs(res$byvar)), ...))
+        res <- c(res,
+                 subgroup(res, NULL,
+                          factor(res$subgroup, bylevs(res$subgroup)), ...))
       else
         res <- c(res, subgroup(res, hcc$tau.resid))
     }
@@ -1488,6 +1547,19 @@ metainc <- function(event.e, time.e, event.c, time.c, studlab,
       res$n.c.w <- NULL
   }
   ##
+  ## Backward compatibility
+  ##
+  res$comb.fixed <- fixed
+  res$comb.random <- random
+  res$level.comb <- level.ma
+  ##
+  if (by) {
+    res$byvar <- subgroup
+    res$bylab <- subgroup.name
+    res$print.byvar <- print.subgroup.name
+    res$byseparator <- sep.subgroup
+  }
+  ##
   class(res) <- c(fun, "meta")
   
   
